@@ -9,6 +9,8 @@ from fabric.decorators import with_settings
 from datetime import timedelta
 from os.path import join as pj
 
+from jinja2 import Environment, FileSystemLoader
+
 JOB_SCHEDULERS = ('SGE', 'SLURM', 'LSF',
                   'PBS', 'TORQUE', 'MAUI', 'LOADLEVELER')
 
@@ -29,8 +31,18 @@ def get_data(filename):
     return fullname
 
 
+def load_template(template_name):
+    env = Environment(loader=FileSystemLoader(
+        os.path.join(os.path.dirname(__file__), 'templates')))
+    return env.get_template(template_name)
+
+
 def detect_scheduling_sys():
 
+    # Test for custom scheduler
+    if os.getenv('MYCLUSTER_SCHED') is not None:
+        return my_import(os.getenv('MYCLUSTER_SCHED'))
+
     # Test for SLURM
     if os.getenv('SLURMHOME') is not None:
         return my_import('mycluster.slurm')
@@ -42,7 +54,6 @@ def detect_scheduling_sys():
     except:
         pass
 
-
     # Test for PBS
     try:
         line = check_output(['pbsnodes', '-a'])
@@ -57,7 +68,7 @@ def detect_scheduling_sys():
     # Test for lsf
     try:
         line = check_output('lsid')
-        if line.split(' ')[0] == 'Platform':
+        if line.split(' ')[0] == 'Platform' or line.split(' ')[0] == 'IBM':
             return my_import('mycluster.lsf')
     except:
         pass
@@ -72,6 +83,13 @@ def queues():
         return []
 
 
+def accounts():
+    if scheduler is not None:
+        return scheduler.accounts()
+    else:
+        return []
+
+
 def remote_sites():
     if job_db is not None:
         return job_db.remote_site_db
@@ -84,8 +102,8 @@ def remote_cmd():
     output_file = '~/.mycluster/' + str(uuid.uuid4())
     with hide('output', 'running', 'warnings'), settings(warn_only=True):
         run('mycluster -p >' + output_file, pty=False)
-        import StringIO
-        contents = StringIO.StringIO()
+        import io
+        contents = io.StringIO()
         get(output_file, contents)
         # operate on 'contents' like a file object here, e.g. 'print
         return contents.getvalue()
@@ -189,8 +207,10 @@ def printjobs(num_lines):
         efficiency = '-'
         if time_ratio:
             try:
-                efficiency = (time_ratio / (int(jobs[j].num_tasks) *
-                              int(jobs[j].threads_per_task)) * 100.0)
+                efficiency = (
+                    time_ratio /
+                    (int(jobs[j].num_tasks) * int(jobs[j].threads_per_task)) *
+                    100.0)
                 efficiency = '{:.1f}'.format(efficiency)
             except:
                 pass
@@ -204,7 +224,8 @@ def printjobs(num_lines):
                                                     status,
                                                     str(jobs[j].num_tasks) +
                                                     ' (' +
-                                                    str(jobs[j].threads_per_task) +
+                                                    str(jobs[j].
+                                                        threads_per_task) +
                                                     ')',
                                                     cputime,
                                                     wallclock,
@@ -218,42 +239,30 @@ def printjobs(num_lines):
             efficiency = '-'
             if time_ratio:
                 try:
-                    efficiency = (time_ratio / (int(jobs[j].num_tasks) *
-                                  int(jobs[j].threads_per_task)) * 100.0)
+                    efficiency = (
+                        time_ratio /
+                        (int(jobs[j].num_tasks) *
+                         int(jobs[j].threads_per_task)) * 100.0)
                     efficiency = '{:.1f}'.format(efficiency)
                 except:
                     pass
-            print('{0:4} | {1:^10} | {2:^10} |\
+            print(
+                '{0:4} | {1:^10} | {2:^10} |\
                    {3:^10} | {4:^12} | {5:^12} |\
-                   {6:^5} | {7:^20} | {8:50}'.format(i + 1,
-                                                     job_id,
-                                                     status,
-                                                     str(jobs[j].num_tasks) +
-                                                     ' (' +
-                                                     str(jobs[j].threads_per_task) +
-                                                     ')',
-                                                     cputime,
-                                                     wallclock,
-                                                     efficiency,
-                                                     jobs[j].job_name,
-                                                     jobs[j].job_dir)
-                  )
+                   {6:^5} | {7:^20} | {8:50}'.
+                format(
+                    i + 1, job_id, status, str(jobs[j].num_tasks) + ' (' +
+                    str(jobs[j].threads_per_task) + ')', cputime, wallclock,
+                    efficiency, jobs[j].job_name, jobs[j].job_dir))
         else:
-            print('{0:4} | {1:^10} | {2:^10} |\
+            print(
+                '{0:4} | {1:^10} | {2:^10} |\
                    {3:^10} | {4:^12} | {5:^12} |\
-                   {6:^5} | {7:^20} | {8:50}'.format(i + 1,
-                                                     job_id,
-                                                     status,
-                                                     str(jobs[j].num_tasks) +
-                                                     ' (' +
-                                                     str(jobs[j].threads_per_task) +
-                                                     ')',
-                                                     '-',
-                                                     '-',
-                                                     efficiency,
-                                                     jobs[j].job_name,
-                                                     jobs[j].job_dir)
-                  )
+                   {6:^5} | {7:^20} | {8:50}'.
+                format(
+                    i + 1, job_id, status, str(jobs[j].num_tasks) + ' (' +
+                    str(jobs[j].threads_per_task) + ')', '-', '-', efficiency,
+                    jobs[j].job_name, jobs[j].job_dir))
 
     remotes = remote_sites()
     for i, j in enumerate(remotes):
@@ -322,7 +331,7 @@ def submit(script_name, immediate, depends=None):
         if job_id is not None:
             print('Job submitted with ID {0}'.format(job_id))
         if job_db is not None and job_id is not None:
-            from persist import Job
+            from .persist import Job
             job = Job(job_id, time.time())
             with open(script_name, 'r') as f:
                 for line in f:
@@ -356,7 +365,7 @@ def delete(job_id):
     scheduler_type = job_db.site_db[site_name].scheduler_type
 
     if (scheduler.name() == site_name and
-       scheduler.scheduler_type() == scheduler_type):
+            scheduler.scheduler_type() == scheduler_type):
         scheduler.delete(job_id)
     else:
         print('JobID: ' + str(job_id) + ' not found at current site')
@@ -410,7 +419,7 @@ def create_directory():
 def create_db():
     global job_db
     try:
-        from persist import JobDB
+        from .persist import JobDB
         job_db = JobDB()
     except Exception as e:
         print('Database failed to initialise. Error Message: ' + str(e))
@@ -487,21 +496,22 @@ def appdata_update(job_id, appdata):
         job_db.get(job_id).appdata(appdata)
 
 
-def init():
+def init(silent=False):
     global scheduler
     scheduler = detect_scheduling_sys()
     created = create_directory()
     if create_db() is not None:
         update_db()
 
-    print('MyCluster Initialisation Info')
-    print('-----------------------------')
-    print('Local database in: ' + get_directory())
-    print('User: ' + get_user())
-    print('Email: ' + get_email())
-    if not scheduler:
-        print('Local job scheduler: None')
-    else:
-        print('Local job scheduler: ' + scheduler.scheduler_type())
-        print('Site name: ' + get_site())
-    print('')
+    if not silent:
+        print('MyCluster Initialisation Info')
+        print('-----------------------------')
+        print('Local database in: ' + get_directory())
+        print('User: ' + get_user())
+        print('Email: ' + get_email())
+        if not scheduler:
+            print('Local job scheduler: None')
+        else:
+            print('Local job scheduler: ' + scheduler.scheduler_type())
+            print('Site name: ' + get_site())
+        print('')
